###################################################################
#####      Code for Nelson et al. 2020, Forests           #########
#####        created 12/18/19                              #########
###################################################################

# Title: The role of climate niche, geofloristic history, habitat preference and allometry on wood density within a California plant community
# Authors: RA Nelson, EJ Francis, JA Berry, WK Cornwell, LDL Anderegg



# load required packages
require(reshape)
require('dplyr')
require("RColorBrewer")
require('lme4')
require('lmerTest')
require(nlme)
require(ggplot2)
require(car) # for the qqp function, isn't loading on LDLA's computer
require(rgbif)
require(ggExtra)
require(MuMIn) #for the AICc, corrected for small sample sizes
require(ggpubr)

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
############### Import Data #######################
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


# note: for all individual-level data, please contact Becca Nelson (rnelson3@stanford.edu) or Leander Anderegg (leanderegg@gmail.com)
# species-level average trait data are included in the manuscript SI:

CA_final <- read.csv("SpeciesTraits_Nelson_et_al_20191218.csv")

#+++++++++++++++++++++++++++++++++++++++++++++++++++++







#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
########### BEGIN: Statistical Analysis ###########################################
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


###### . Riparian specialist and taper analysis #########
### Model Selection for WD, taper, and streambank
model_null<- (lm(WD~1, CA_final))
model_taper<- (lm(WD~taper, CA_final))
model_stream <- (lm(WD~Streambanks, CA_final))
model_both <- (lm(WD~taper+Streambanks, CA_final))
model_interact <- (lm(WD~taper+Streambanks +taper:Streambanks, CA_final))
model_interact_slope <- lm(WD~taper - Streambanks + taper:Streambanks, CA_final)
AICc(model_null, model_taper, model_stream, model_both, model_interact, model_interact_slope)

# model_null            2 -24.21965
# model_taper           3 -22.29029
# model_stream          3 -31.84063
# model_both            4 -29.21682
# model_interact        5 -29.49310
# model_interact_slope  4 -32.95175


anova(model_stream, model_interact_slope)

### produces a number of 'model criticism' plots
# to check model assumptions. (normality of resids, no major outliers)

plot(model_stream)
plot(model_interact_slope)




####. Geoflora analysis ####
# note: we have currently 4 categories of geoflora. 'unknown' (empty), "Arcto", "Madro", and "both"
# technically, this means we fit four different params. I think we should drop everything that's uncertain and just fit two params (arcto and Madro)
model_null <- (lm(WD~1, CA_final[which(CA_final$Geoflora.Type %in% c("Arcto-Tertiary","Madro-Tertiary")),]))
model_geoflora <- (lm(WD~Geoflora.Type, CA_final[which(CA_final$Geoflora.Type %in% c("Arcto-Tertiary","Madro-Tertiary")),]))

AIC(model_null, model_geoflora)
anova(model_null, model_geoflora)



########.  Wet edge climate effects #############

model_CMD <- lm(WD~CMD.05, CA_final)
model_MAP <- lm(WD~MAP.05, CA_final)
model_PET <- lm(WD~PET.05, CA_final)
model_MAT <- lm(WD~MAT.05, CA_final)
AICc(model_null, model_CMD, model_MAP, model_PET, model_MAT, model_interact_slope)
  # CMD.05 best predictor

## now performing model selection with CMD and streambanks
model_CMD <- lm(WD~CMD.05, CA_final)
model_CMD1 <- lm(WD~CMD.05 + Streambanks, CA_final)
model_CMD2 <- lm(WD~CMD.05*Streambanks - Streambanks, CA_final)
model_CMD3 <- lm(WD~CMD.05*Streambanks, CA_final)
AICc(model_CMD, model_CMD1, model_CMD2, model_CMD3)
# main effects for both is the best model



### Finally, select the best full model based on the best structural model
# (taper : Streambanks + taper) and the best climate model (Streambanks + CMD.05)
# (Note, some of these we already know are going to be bad, but just doing it for the sake of completenes)
model_all1 <- lm(WD~CMD.05 + taper + Streambanks + taper:Streambanks,  CA_final ) # entire model, main effects for all, and taper/streambanks interaction
model_all2 <- lm(WD~CMD.05 + taper*Streambanks - Streambanks,  CA_final) # drop the main effect for Streambanks
model_all3 <- lm(WD~ taper*Streambanks,  CA_final) # drop the main effect for CMD.05
model_all4 <- lm(WD~ CMD.05 + Streambanks,  CA_final) # drop the main effect for Taper
model_all5 <- lm(WD~  Streambanks,  CA_final) # drop the main effect for Taper
model_all6 <- lm(WD~ CMD.05 ,  CA_final) # drop the main effect for Taper
model_all7 <- lm(WD~ taper,  CA_final) # drop the main effect for CMD.05

AICc(model_null, model_CMD, model_all1, model_all2, model_all3, model_all4, model_all5, model_all6, model_all7)
# model_all2 is the best by a looong ways
#             df      AICc
# model_null  2 -24.21965
# model_CMD   3 -29.20684
# model_all1  6 -37.75583
# model_all2  5 -41.73679
# model_all3  5 -29.49310
# model_all4  4 -36.06615
# model_all5  3 -31.84063
# model_all6  3 -29.20684
# model_all7  3 -22.29029
summary(model_all2)



######. Variance decomposition of the climate and structural factors #########
# theory behind variance decomp: 
# variance explained by the full model = var by predictor 1 + var by predictor 2 + shared var explained by 1 & 2
# so the R squareds of the 'subset' models can be used to partition the R squared of the full model into
# variance components due 'purely' to each predictor and that shared between them

cmd_rsq <- summary(model_CMD)$r.squared
# updated: 0.322 - variance explained by CMD 
int_slope_rsq <- summary(model_interact_slope)$r.squared
# update: 0.520 - best model of taper and riparian habitat

full_rsq <- summary(model_all2)$r.squared
# update: 0.742 

cmd_rsq + int_slope_rsq 
# 0.843

# Update: 0.5887 - without Sequoia.
full_rsq - cmd_rsq - int_slope_rsq
# so it looks like there's 10.1% of the variance that is shared between climate and taper




#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
########### END: Statistical Analysis ###########################################
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++







#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
########### BEGIN: Data Visualization ###########################################
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++




#### Figure 2: Wood density vs BD:HT by streambank #########

plot(WD~taper, CA_final, col=Streambanks, pch=16, xlab="Basal Diameter to Height Ratio", ylab="Wood Density")
# pull out predictions from model
pred.streambanks <- predict(model_interact_slope,
                            newdata = list("taper"=c(min(CA_final$taper[which(CA_final$Streambanks=="Yes")]), max(CA_final$taper[which(CA_final$Streambanks=="Yes")])),"Streambanks"=c("Yes","Yes")))
lines(pred.streambanks~c(min(CA_final$taper[which(CA_final$Streambanks=="Yes")]), max(CA_final$taper[which(CA_final$Streambanks=="Yes")])), CA_final, col=2, lwd=2)
pred.ns <- predict(model_interact_slope,
                   newdata = list("taper"=c(min(CA_final$taper[which(CA_final$Streambanks=="No")]), max(CA_final$taper[which(CA_final$Streambanks=="No")])),"Streambanks"=c("No","No")))
lines(pred.ns~c(min(CA_final$taper[which(CA_final$Streambanks=="No")]), max(CA_final$taper[which(CA_final$Streambanks=="No")])), CA_final, col=1, lwd=2)


pred.streambanks <- predict(model_stream,
                            newdata = list("taper"=c(min(CA_final$taper[which(CA_final$Streambanks=="Yes")]), max(CA_final$taper[which(CA_final$Streambanks=="Yes")])),"Streambanks"=c("Yes","Yes")))
lines(pred.streambanks~c(min(CA_final$taper[which(CA_final$Streambanks=="Yes")]), max(CA_final$taper[which(CA_final$Streambanks=="Yes")])), CA_final, col=2, lwd=2, lty=3)
pred.ns <- predict(model_stream,
                   newdata = list("taper"=c(min(CA_final$taper[which(CA_final$Streambanks=="No")]), max(CA_final$taper[which(CA_final$Streambanks=="No")])),"Streambanks"=c("No","No")))
lines(pred.ns~c(min(CA_final$taper[which(CA_final$Streambanks=="No")]), max(CA_final$taper[which(CA_final$Streambanks=="No")])), CA_final, col=1, lwd=2, lty=3)

legend(x=-0.8, y=.95, xpd=T, legend=c("Riparian", "Non-Riparian"), col=c(2,1), pch=16, bty="n", cex=.8)
legend(x=2.5, y=.95, xpd=T, legend=c("interaction", "main effect"), lwd=3, lty=c(1,3), bty="n", cex=.8)




##### Figure 3: Wood density vs climate signals by streambank #######

#new figure 3: two panels with climate

quartz(width=6.5, height=3.5)
par(mfrow=c(1,2), mar=c(4.5, 4.5, 2,1))


# panel a) CMD 05 & 95
clim.var <- "CMD"
trait <- "WD"
xmin <- min(CA_final[,grep(clim.var, colnames(CA_final))])
xmax <- max(CA_final[,grep(clim.var, colnames(CA_final))])
plot(get(trait)~get(paste0(clim.var, ".05")), CA_final, xlim=c(xmin, xmax), xlab="CMD (PET - MAP, mm)", ylab="Wood Density")
legend(x=xmin, y=max(CA_final[,trait], na.rm=T)+.001*max(CA_final[,trait], na.rm=T)+.115, xpd=T, legend = c("5th percentile", "95th percentile"), pch=c(1,3), ncol=1, bty="n")
points(get(trait)~get(paste0(clim.var, ".95")), CA_final, pch=3)
# draw lines if there are significant relationships
mod05 <- lm(get(trait)~get(paste0(clim.var, ".05")), CA_final)
mod95 <- lm(get(trait)~get(paste0(clim.var, ".95")), CA_final)
if(summary(mod05)$coefficients[2,4]<0.05){
  lines(mod05$fitted.values~mod05$model[,2])
  #mtext(text = paste0("p=",round(summary(mod05)$coefficients[2,4],4)), side = 3, line = 0.5, adj = 0.8)
}
mtext(text = "a)", side=3, adj = -0.2, line=1, font=2)

#Panel B
plot(WD~CMD.05, CA_final, col=Streambanks, 
     xlab = "5th Percentile CMD (mm)", ylab = "Wood Density",
     pch=16)
mtext(text = "b)", side=3, adj = -0.2, line=1, font=2)






##### Figures 4 and 5: WD vs Climate by Geoflora ##########
COPY <-data.frame(CA_final)

COPY1 <- COPY[-c(11, 16, 18), ] 

#FINAL FIGURE 4:

# Panel A
a <- ggplot(COPY1, aes(CMD.05, WD, colour=Geoflora.Type)) + geom_point(size=(3)) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("5th Percentile CMD") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Wood Density") +
  theme(axis.title.y = element_text(color="black", size=18)) 


#Panel B
b <- ggplot(COPY1, aes(Tmin.05, WD, colour=Geoflora.Type)) + geom_point(size=(3)) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("5th Percentile Tmin") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Wood Density") +
  theme(axis.title.y = element_text(color="black", size=18))

#Panel C
c <- ggplot(COPY1, aes(CMD.05, taper, colour=Geoflora.Type)) + geom_point(size=(3)) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("5th Percentile CMD") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Taper") +
  theme(axis.title.y = element_text(color="black", size=18))

#Panel D
d <- ggplot(COPY1, aes(Tmin.05, taper, colour=Geoflora.Type)) + geom_point(size=(3)) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("5th Percentile Tmin") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Taper") +
  theme(axis.title.y = element_text(color="black", size=18))

#FINAL FIGURE 5:

#Panel a
e <- ggplot(COPY1, aes(as.character(Geoflora.Type), WD)) +
  geom_boxplot(outlier.shape = NA) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("Geoflora Type") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Wood Density") +
  theme(axis.title.y = element_text(color="black", size=18))

#Panel b
f <- ggplot(COPY1, aes(as.character(Geoflora.Type), taper)) +
  geom_boxplot(outlier.shape = NA) +
  theme_classic() +
  theme(legend.title = element_text(colour="black", size=16)) +
  theme(legend.text = element_text(colour="black", size=14)) +
  xlab("Geoflora Type") +
  theme(axis.title.x = element_text(color="black", size=18)) +
  ylab("Taper") +
  theme(axis.title.y = element_text(color="black", size=18))

#Figure 4
quartz(width=6.5, height=7)
ggarrange(a, b, c, d, ncol=2, nrow=2, labels = c("a", "b", "c", "d"), common.legend = TRUE)
quartz.save("Figure 4 new", type="pdf")

#Figure 5
quartz(width=6.5, height=3.5)
ggarrange(e, f, ncol=2, nrow=1, labels = c("a", "b"), common.legend = TRUE)
quartz.save("Figure 5", type="pdf")








######### Figure 6: Final Model visualization ##############
# and this is sort of what the interaction looks like:
# first make a new column with the actual names "riparian" "non-riparian" that we want facets to display
CA_final$Rip.forplotting <- CA_final$Streambanks
levels(CA_final$Rip.forplotting) <- list('Riparian' = "Yes", 'Non-Riparian'= "No")
quartz(width=6, height=3.2)
ggplot(CA_final, aes(x=taper, y=WD, col=CMD.05)) + geom_point() + facet_wrap(~Rip.forplotting) + geom_smooth(method="lm", se=T, col='black') + labs(col= "5% CMD (mm)") + xlab("Taper (BD:H ratio)")

# or without st errors for lines
ggplot(CA_final, aes(x=taper, y=WD, col=CMD.05)) + geom_point() + facet_wrap(~Rip.forplotting) + geom_smooth(method="lm", se=F, col='black') + labs(col= "5% CMD (mm)") + xlab("Taper (BD:H ratio)")







###. Quick exploration of climate ranges ##############
# NOTE: This plots the relationship between a trait and the 5th and 95th percentile of a climate variable
# this is for visual exploration only, but was how we determined that the wet edge
# is consistently related to WD, but the dry edge is not.


plotclim <- function(clim.var, trait){
  # get the min and max xlim for plotting
  xmin <- min(CA_final[,grep(clim.var, colnames(CA_final))])
  xmax <- max(CA_final[,grep(clim.var, colnames(CA_final))])
  plot(get(trait)~get(paste0(clim.var, ".05")), CA_final, xlim=c(xmin, xmax), xlab=clim.var, ylab=trait)
  legend(x=xmin, y=max(CA_final[,trait], na.rm=T)+.001*max(CA_final[,trait], na.rm=T)+.1, xpd=T, legend = c("5th percentile", "95th percentile"), pch=c(1,3), ncol=1, bty="n")
  points(get(trait)~get(paste0(clim.var, ".95")), CA_final, pch=3)
  # draw lines if there are significant relationships
  mod05 <- lm(get(trait)~get(paste0(clim.var, ".05")), CA_final)
  mod95 <- lm(get(trait)~get(paste0(clim.var, ".95")), CA_final)
  if(summary(mod05)$coefficients[2,4]<0.05){
    lines(mod05$fitted.values~mod05$model[,2])
    mtext(text = paste0("p=",round(summary(mod05)$coefficients[2,4],4)), side = 3, line = 0.5, adj = 0.8)
  }
  if(summary(mod95)$coefficients[2,4]<0.05){
    lines(mod95$fitted.values~mod95$model[,2])
    mtext(text = paste0("p=",round(summary(mod95)$coefficients[2,4],4)), side = 3, line = 0.5, adj = 0.8)
  }
}


plotclim(clim.var="CMD", trait="WD")
plotclim(clim.var="MAP", trait="WD")
plotclim(clim.var="PET", trait="WD")
plotclim(clim.var="MAT", trait="WD")
plotclim(clim.var="Tmin", trait="WD")
plotclim(clim.var="Tmax", trait="WD")
plotclim(clim.var="Pseason", trait="WD")



plotclim(clim.var="CMD", trait="taper")
plotclim(clim.var="MAP", trait="taper")
plotclim(clim.var="PET", trait="taper")
plotclim(clim.var="MAP", trait="taper")
plotclim(clim.var="Tmin", trait="taper")
plotclim(clim.var="Tmax", trait="taper")
plotclim(clim.var="Pseason", trait="taper")









########## SUPPLEMENTAL FIGURE: Stanford vs JR  ##############
quartz(width=6, height=3.5)
par(mfrow=c(1,2), mar=c(4,4,2,1))
plot(WD~taper, col=Streambanks, CA_final[grep("JR", CA_final$study),], xlab="Taper",ylab="Wood Density", main="Jasper Ridge", ylim=c(0.4,0.82))
legend('bottomright', legend = c("riparian", "non-rip"), pch=1, col=c("red","black"))
plot(WD~taper, col=Streambanks, CA_final[grep("Stanford", CA_final$study),], xlab="Taper",ylab="Wood Density", main="Stanford", ylim=c(0.4,0.82))

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++






#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
########### BEGIN: Phylogeny generation, phylopgls ###########################################
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++



require(stringr)
require(taxize)
require(brranching)
require(ape)
require(dplyr)
require(geiger)
require(nlme)

spplist <- CA_final$Species
## clean the names with taxize:
#taxize::use_entrez()
#usethis::edit_r_environ()
spplist_phylo <- phylomatic_names(spplist)
spp_phylo <- phylomatic(spplist_phylo)
  # this is an easy phylogeny, but doesn't have branch lengths...

# also add a genus column
CA_final$Genus <- str_split(string = CA_final$Species, pattern = "\\ ", simplify = T)[,1]
CA_final$Genus_species <- str_replace(CA_final$Species,"\\ ","_")

rownames(CA_final)<- CA_final$Genus_species
rownames(CA_final)[which(CA_final$Genus_species=="Prunus_ilicifolia")] <- "Prunus_ilicifolia_subsp._ilicifolia"
rownames(CA_final)[which(CA_final$Genus_species=="Baccharis_pilularis")] <- "Baccharis_halimifolia"
# changing two species names, one to be the subspp, the other to insert a random Baccharis (lengths shouldn't matter)


# column for species without congeners
CA_final$congener <- "no"
CA_final$congener[which(CA_final$Genus %in% c("Acer","Prunus","Quercus","Salix"))] <- "yes"




##### Smith & Brown 2018 phylogeny ###
big <- read.tree("./Smith_Brown_2018_phylogenies/ALLMB.tre")
  # downloaded from: https://github.com/FePhyFoFum/big_seed_plant_trees
  # on 17 Dec 2019 (v0.1)

totrim <- name.check(big, CA_final)
trimmed <- drop.tip(big, tip = totrim$tree_not_data)




### branch lengths
# this isn't a dated phylogeny, so we'll just calculate branch lengths from the topology
spp_phylo <- compute.brlen(spp_phylo)

### define the covariance structure based on the phylogeny and assumed Brownian motion
bm<-corBrownian(1, trimmed)
# bm
# now use gls from nlme to fit the same linear models:
model_interact_slope <- gls(WD~taper - Streambanks + taper:Streambanks, CA_final, correlation=bm)

model_CMD <- gls(WD~CMD.05, CA_final, correlation=bm)

model_all2 <- gls(WD~CMD.05 + taper*Streambanks - Streambanks,  CA_final, correlation = bm) # drop the main effect for Streambanks




### SUPPLEMENTAL FIGURE: Results with congeners highlighted ##############

quartz(width=6, height=3.)
par(mfrow=c(1,2), mar=c(4.5, 4.5, 2.5,1))
plot(WD~taper, CA_final, pch=as.numeric(Streambanks)+15, ylab="Wood Density", xlab="Taper (BD:Height)")
points(WD~taper, CA_final[which(CA_final$congener=="yes"),], cex=1.1, col=factor(Genus), pch=as.numeric(Streambanks)+15)
legend(x=1, y=.95, legend=c("Acer","Prunus","Quercus","Salix"), pch=16, col=1:4, bty="n", xpd=NA, ncol=2)

plot(WD~CMD.05, CA_final, pch=as.numeric(Streambanks)+15, ylab="Wood Density", xlab="5th % CMD")
points(WD~CMD.05, CA_final[which(CA_final$congener=="yes"),], cex=1.1, col=factor(Genus), pch=as.numeric(Streambanks)+15)

